agentle.agents.conversations.conversation\_store
================================================

.. automodule:: agentle.agents.conversations.conversation_store

   
   .. rubric:: Classes

   .. autosummary::
   
      AssistantMessage
      ConversationStore
      DeveloperMessage
      Sequence
      UserMessage
   